# Download attachments from SendSafely

Ssgrab is a utility for downloading attachments to tickets from
[SendSafely](https://www.sendsafely.com) and decrypting them. There is
integration with [zdgrab](https://github.com/fprimex/zdgrab) for downloading
SendSafely package links included in ticket comments.
